@@ -27,8 +27,7 @@ def get_directory():
     if getattr(mezz_settings, "MEDIA_LIBRARY_PER_SITE", False):
         dirname = os.path.join(dirname, "site-%s" % current_site_id())
     fullpath = os.path.join(mezz_settings.MEDIA_ROOT, dirname)
-    if not default_storage.exists(fullpath):
-        import pdb; pdb.set_trace()
+    if not default_storage.isdir(fullpath):
         default_storage.makedirs(fullpath)
     return dirname
 
